@@ -306,6 +306,7 @@ on_session_open_failed (GdmSession      *session,
 
 static void
 on_session_session_started (GdmSession      *session,
+                            int              pid,
                             GdmFactorySlave *slave)
 {
         g_debug ("GdmFactorySlave: Relay session started");
@@ -436,14 +437,6 @@ on_greeter_language_selected (GdmGreeterServer *greeter_server,
         gdm_session_select_language (GDM_SESSION (slave->priv->session), text);
 }
 
-static void
-on_greeter_layout_selected (GdmGreeterServer *greeter_server,
-                            const char       *text,
-                            GdmFactorySlave  *slave)
-{
-        gdm_session_select_layout (GDM_SESSION (slave->priv->session), text);
-}
-
 static void
 on_greeter_user_selected (GdmGreeterServer *greeter_server,
                           const char       *text,
@@ -536,10 +529,6 @@ run_greeter (GdmFactorySlave *slave)
                           "language-selected",
                           G_CALLBACK (on_greeter_language_selected),
                           slave);
-        g_signal_connect (slave->priv->greeter_server,
-                          "layout-selected",
-                          G_CALLBACK (on_greeter_layout_selected),
-                          slave);
         g_signal_connect (slave->priv->greeter_server,
                           "user-selected",
                           G_CALLBACK (on_greeter_user_selected),
