@@ -28,7 +28,7 @@
 #include "gdm-session-private.h"
 
 enum {
-        OPENED = 0,
+        CONVERSATION_STARTED = 0,
         SETUP_COMPLETE,
         SETUP_FAILED,
         RESET_COMPLETE,
@@ -44,13 +44,14 @@ enum {
         PROBLEM,
         INFO_QUERY,
         SECRET_INFO_QUERY,
+        SESSION_OPENED,
+        SESSION_OPEN_FAILED,
         SESSION_STARTED,
         SESSION_START_FAILED,
         SESSION_EXITED,
         SESSION_DIED,
         SELECTED_USER_CHANGED,
         DEFAULT_LANGUAGE_NAME_CHANGED,
-        DEFAULT_LAYOUT_NAME_CHANGED,
         DEFAULT_SESSION_NAME_CHANGED,
         LAST_SIGNAL
 };
@@ -78,11 +79,11 @@ gdm_session_get_type (void)
 }
 
 void
-gdm_session_open (GdmSession *session)
+gdm_session_start_conversation (GdmSession *session)
 {
         g_return_if_fail (GDM_IS_SESSION (session));
 
-        GDM_SESSION_GET_IFACE (session)->open (session);
+        GDM_SESSION_GET_IFACE (session)->start_conversation (session);
 }
 
 void
@@ -164,15 +165,6 @@ gdm_session_select_language (GdmSession *session,
         GDM_SESSION_GET_IFACE (session)->select_language (session, text);
 }
 
-void
-gdm_session_select_layout (GdmSession *session,
-                           const char *text)
-{
-        g_return_if_fail (GDM_IS_SESSION (session));
-
-        GDM_SESSION_GET_IFACE (session)->select_layout (session, text);
-}
-
 void
 gdm_session_select_user (GdmSession *session,
                          const char *text)
@@ -190,6 +182,14 @@ gdm_session_cancel (GdmSession *session)
         GDM_SESSION_GET_IFACE (session)->cancel (session);
 }
 
+void
+gdm_session_open_session (GdmSession *session)
+{
+        g_return_if_fail (GDM_IS_SESSION (session));
+
+        GDM_SESSION_GET_IFACE (session)->open_session (session);
+}
+
 void
 gdm_session_start_session (GdmSession *session)
 {
@@ -203,11 +203,11 @@ gdm_session_class_init (gpointer g_iface)
 {
         GType iface_type = G_TYPE_FROM_INTERFACE (g_iface);
 
-        signals [OPENED] =
-                g_signal_new ("opened",
+        signals [CONVERSATION_STARTED] =
+                g_signal_new ("conversation-started",
                               iface_type,
                               G_SIGNAL_RUN_FIRST,
-                              G_STRUCT_OFFSET (GdmSessionIface, opened),
+                              G_STRUCT_OFFSET (GdmSessionIface, conversation_started),
                               NULL,
                               NULL,
                               g_cclosure_marshal_VOID__VOID,
@@ -363,6 +363,27 @@ gdm_session_class_init (gpointer g_iface)
                               G_TYPE_NONE,
                               1,
                               G_TYPE_STRING);
+        signals [SESSION_OPENED] =
+                g_signal_new ("session-opened",
+                              iface_type,
+                              G_SIGNAL_RUN_FIRST,
+                              G_STRUCT_OFFSET (GdmSessionIface, session_opened),
+                              NULL,
+                              NULL,
+                              g_cclosure_marshal_VOID__VOID,
+                              G_TYPE_NONE,
+                              0);
+        signals [SESSION_OPEN_FAILED] =
+                g_signal_new ("session-open-failed",
+                              iface_type,
+                              G_SIGNAL_RUN_FIRST,
+                              G_STRUCT_OFFSET (GdmSessionIface, session_open_failed),
+                              NULL,
+                              NULL,
+                              g_cclosure_marshal_VOID__STRING,
+                              G_TYPE_NONE,
+                              1,
+                              G_TYPE_STRING);
         signals [SESSION_STARTED] =
                 g_signal_new ("session-started",
                               iface_type,
@@ -439,17 +460,6 @@ gdm_session_class_init (gpointer g_iface)
                               G_TYPE_NONE,
                               1,
                               G_TYPE_STRING);
-        signals [DEFAULT_LAYOUT_NAME_CHANGED] =
-                g_signal_new ("default-layout-name-changed",
-                              iface_type,
-                              G_SIGNAL_RUN_FIRST,
-                              G_STRUCT_OFFSET (GdmSessionIface, default_layout_name_changed),
-                              NULL,
-                              NULL,
-                              g_cclosure_marshal_VOID__STRING,
-                              G_TYPE_NONE,
-                              1,
-                              G_TYPE_STRING);
         signals [DEFAULT_SESSION_NAME_CHANGED] =
                 g_signal_new ("default-session-name-changed",
                               iface_type,
@@ -575,6 +585,21 @@ _gdm_session_problem (GdmSession   *session,
         g_signal_emit (session, signals [PROBLEM], 0, text);
 }
 
+void
+_gdm_session_session_opened (GdmSession   *session)
+{
+        g_return_if_fail (GDM_IS_SESSION (session));
+        g_signal_emit (session, signals [SESSION_OPENED], 0);
+}
+
+void
+_gdm_session_session_open_failed (GdmSession   *session,
+                                  const char   *text)
+{
+        g_return_if_fail (GDM_IS_SESSION (session));
+        g_signal_emit (session, signals [SESSION_OPEN_FAILED], 0, text);
+}
+
 void
 _gdm_session_session_started (GdmSession   *session,
                               int           pid)
@@ -608,10 +633,10 @@ _gdm_session_session_died (GdmSession   *session,
 }
 
 void
-_gdm_session_opened (GdmSession   *session)
+_gdm_session_conversation_started (GdmSession   *session)
 {
         g_return_if_fail (GDM_IS_SESSION (session));
-        g_signal_emit (session, signals [OPENED], 0);
+        g_signal_emit (session, signals [CONVERSATION_STARTED], 0);
 }
 
 void
@@ -630,15 +655,6 @@ _gdm_session_default_language_name_changed (GdmSession   *session,
         g_signal_emit (session, signals [DEFAULT_LANGUAGE_NAME_CHANGED], 0, language_name);
 }
 
-void
-_gdm_session_default_layout_name_changed (GdmSession   *session,
-                                          const char   *layout_name)
-{
-        g_return_if_fail (GDM_IS_SESSION (session));
-
-        g_signal_emit (session, signals [DEFAULT_LAYOUT_NAME_CHANGED], 0, layout_name);
-}
-
 void
 _gdm_session_default_session_name_changed (GdmSession   *session,
                                            const char   *session_name)
