@@ -61,8 +61,6 @@ struct _GdmSessionIface
                                               const char   *text);
         void (* select_language)             (GdmSession   *session,
                                               const char   *text);
-        void (* select_layout)               (GdmSession   *session,
-                                              const char   *text);
         void (* select_session)              (GdmSession   *session,
                                               const char   *text);
         void (* select_user)                 (GdmSession   *session,
@@ -114,8 +112,6 @@ struct _GdmSessionIface
 
         void (* default_language_name_changed)    (GdmSession   *session,
                                                    const char   *text);
-        void (* default_layout_name_changed)      (GdmSession   *session,
-                                                   const char   *text);
         void (* default_session_name_changed)     (GdmSession   *session,
                                                    const char   *text);
 };
@@ -143,8 +139,6 @@ void     gdm_session_select_session              (GdmSession *session,
                                                   const char *session_name);
 void     gdm_session_select_language             (GdmSession *session,
                                                   const char *language);
-void     gdm_session_select_layout               (GdmSession *session,
-                                                  const char *language);
 void     gdm_session_select_user                 (GdmSession *session,
                                                   const char *username);
 void     gdm_session_cancel                      (GdmSession *session);
